@@ -1,3 +1,4 @@
+from decimal import Decimal
 import time
 from typing import Tuple, Dict, Any
 from web3 import HTTPProvider, Web3
@@ -35,17 +36,19 @@ ERC20_APPROVE_ABI = """[{"constant":false,"inputs":[{"name":"_spender","type":"a
 
 ERC20_TRANSFER_ABI = """[{"constant":false,"inputs":[{"name":"recipient","type":"address"},{"name":"amount","type":"uint256"}],"name":"transfer","outputs":[{"name":"","type":"bool"}],"payable":false,"stateMutability":"nonpayable","type":"function"}]"""
 
-def mpc_transfer(mpc_address: WalletAddress, destination, chain_raw, token_raw, token_address, amount):
+def mpc_transfer(mpc_address: WalletAddress, destination, chain_raw, token_raw, token_address, amount: float):
     tx_hash = None
     try:
         if chain_raw == 'base' and token_raw == 'usdc':
-            transfer = mpc_address.transfer(amount, 'usdc', destination, gasless=True)
+            transfer = mpc_address.transfer(Decimal(str(amount)), 'usdc', destination, gasless=True)
+            print(f"mpc transfer amount: {amount}", flush=True)
+            # transfer = mpc_address.transfer(amount, 'usdc', destination, gasless=True)
             try:
                 transfer.wait()
             except Exception as e:
                 print(f"Transfer error: {e}", flush=True)
 
-            timeout = 10  
+            timeout = 20  
             start_time = time.time()
             while str(transfer.status) not in ['complete','failed']:
                 if time.time() - start_time > timeout:
@@ -85,14 +88,18 @@ def mpc_transfer(mpc_address: WalletAddress, destination, chain_raw, token_raw,
             #     args={"to": destination, "value": amount_to_transfer}
             # )
             info = {
-                "content": f"In automatic mode, only USDC transfers on the Base mainnet are supported.",
+                "content": f"Unsupported token in auto mode. You can try using manual mode.",
                 "code": 500
             }
             return info
     except Exception as e:
+        error_message = str(e)
+        if "Insufficient funds" in error_message:
+            error_message += " You need to first deposit USDC into the asset."
+            
         print(f"Exception occurred: {e}, Tx hash: {tx_hash}", flush=True)
         info = {
-            "content": f"{e}",
+            "content": error_message,
             "code": 500
         }
         return info
@@ -156,12 +163,12 @@ def transfer(receiver: str, amount: float, step: any, chain: str = "base", token
     else:
         return handle_manual_transfer(w3, eth_w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw)
 
-def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw):
+def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amount: float, token_address, redis_client, chain_raw, token_raw):
     if token_raw == 'usdc' and chain_raw == 'base':
         try:
             code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
             if code != 200:
-                return {'result': {"content": f"Cannot find {receiver} on contacts", "code": 420}, 'action': None, 'next_action': None}
+                return {'result': {"content": f"{receiver_address}", "code": 420}, 'action': None, 'next_action': None}
 
             to = w3.to_checksum_address(receiver_address)
             executor = w3.to_checksum_address(executor)
@@ -172,13 +179,13 @@ def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amou
         except Exception as e:
             return handle_auto_transfer_error(e)
     else:
-        token = token_raw.upper()
-        if token_raw in ['btc', 'cbbtc', 'wbtc']:
-            if chain_raw == 'base':
-                token = 'cbBTC'
-            else:
-                token = 'WBTC'
-        return {'result': {"code": 500, "content": f"Transfers of the current currency({token}) are not supported in automatic mode."}, 'action': None, 'next_action': None}
+        # token = token_raw.upper()
+        # if token_raw in ['btc', 'cbbtc', 'wbtc']:
+        #     if chain_raw == 'base':
+        #         token = 'cbBTC'
+        #     else:
+        #         token = 'WBTC'
+        return {'result': {"code": 500, "content": f"Unsupported token in auto mode. You can try using manual mode."}, 'action': None, 'next_action': None}
         
 
 def handle_manual_transfer(w3: Web3, eth_w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw):
@@ -194,7 +201,7 @@ def handle_manual_transfer(w3: Web3, eth_w3, executor, receiver, amount, token_a
     
     code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
     if code != 200:
-        return {'result': {"content": f"Cannot find {receiver} on contact", "code": 420}, 'action': None, 'next_action': None}
+        return {'result': {"content": f"{receiver_address}", "code": 420}, 'action': None, 'next_action': None}
 
     amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
     to = w3.to_checksum_address(receiver_address)
@@ -347,4 +354,4 @@ def decode_custom_error(contract_abi, w3, error) -> Tuple[str, str]:
                 params = ','.join([str(x) for x in w3.codec.decode(data_types,bytes.fromhex(error[10:]))])
                 #decoded = "%s(%s)" % (name , str(params))
                 return name, params
-    return None, None #try other contracts until result is not None since error may be raised from another called contract
\ No newline at end of file
+    return None, None #try other contracts until result is not None since error may be raised from another called contract
