@@ -1,29 +1,6 @@
-from web3 import Web3
-
-from actions_lib.actions.consts import TOKEN_MAPPING
-
-ERC20_ABI = [
-    {
-        "constant": True,
-        "inputs": [{"name": "_owner", "type": "address"}],
-        "name": "balanceOf",
-        "outputs": [{"name": "balance", "type": "uint256"}],
-        "type": "function",
-    },
-    {
-        "constant": True,
-        "inputs": [],
-        "name": "decimals",
-        "outputs": [{"name": "", "type": "uint8"}],
-        "type": "function",
-    },
-]
-
 def show_account_info(step: any, **kwargs):
     redis_client = kwargs.get('redis_client')
     executor = kwargs.get('executor')
-    providers = kwargs.get("providers")
-    w3 = providers['base']['w3']
     mpc_address = kwargs.get('mpc_address')
     result = {}
     account_info = get_account_info(redis_client, executor)
@@ -64,17 +41,6 @@ def get_extra_funds(redis_client, account_id):
 def get_base_usdc_mpc_balance(mpc_address):
     return float(mpc_address.balance('usdc'))
 
-def get_base_usdc_balance(address: str, w3: Web3) -> float:
-    address = Web3.to_checksum_address(address)
-    # usdc_address = Web3.to_checksum_address(TOKEN_MAPPING['base']['usdc']['address'])
-    usdc_address = Web3.to_checksum_address("0x036CbD53842c5426634e7929541eC2318f3dCF7e")
-    usdc_contract = w3.eth.contract(
-        address=usdc_address,
-        abi=ERC20_ABI
-    )
-    raw_balance = usdc_contract.functions.balanceOf(address).call()
-    return raw_balance
-
 def get_user_base_assets(mpc_address):
     result = []
     try:
@@ -85,24 +51,6 @@ def get_user_base_assets(mpc_address):
         result.append({'chain': 'Base', 'token': 'USDC', 'amount': 0 })
     return result
 
-# def get_user_assets(redis_client, user_id, w3, mpc_address):
-#     result = []
-#     chain = 'base-sepolia'
-#     user_id = user_id.lower()
-#     chain = chain.lower()   
-#     key = f"mpc_address:{user_id}:{chain}"
-    
-#     redis_data = redis_client.hgetall(key)
-#     if not redis_data:
-#         result.append({'chain': 'Base', 'token': 'USDC', 'amount': 0 })
-#         return result
-#     else:
-#         # usdc_balance = get_base_usdc_balance(redis_data['wallet_address'], w3)
-#         usdc_balance = get_base_usdc_mpc_balance(mpc_address)
-#         print(f"usdc_balance: {usdc_balance}", flush=True)
-#         result.append({'chain': 'Base', 'token': 'USDC', 'amount': usdc_balance})
-#         return result
-
 def generate_complete_markdown(user_address, ai_balance, assets):
     """
     Generate a complete Markdown report with user info and assets.
